This package contains function to compute Bayes factors for a number of research designs and hypotheses, including t tests, ANOVA, and linear regression, and contingency tables.
| Package: | BayesFactor |
| Type: | Package |
| Version: | 0.9.12 |
| Date: | 2015-4-20 |
| License: | GPL 2.0 |
| LazyLoad: | yes |
The following methods are currently implemented, with more to follow:
general linear models (including linear mixed effects models): generalTestBF, lmBF
linear regression: regressionBF, lmBF,
linearReg.R2stat;
t tests: ttestBF, ttest.tstat;
meta-analytic t tests: meta.ttestBF
ANOVA: anovaBF, lmBF, oneWayAOV.Fstat;
contingency tables: contingencyTableBF;
single proportions: proportionBF;
Other useful functions: posterior, for sampling from posterior
distributions; recompute, for re-estimating a Bayes factor or
posterior distribution; compare, to compare two model
posteriors; and plot.BFBayesFactor, for plotting Bayes factor
objects.
Liang, F. and Paulo, R. and Molina, G. and Clyde, M. A. and Berger, J. O. (2008). Mixtures of g-priors for Bayesian Variable Selection. Journal of the American Statistical Association, 103, pp. 410-423
Rouder, J. N., Speckman, P. L., Sun, D., Morey, R. D., \& Iverson, G. (2009). Bayesian t-tests for accepting and rejecting the null hypothesis. Psychonomic Bulletin & Review, 16, 225-237
Rouder, J. N., Morey, R. D., Speckman, P. L., Province, J. M., (2012) Default Bayes Factors for ANOVA Designs. Journal of Mathematical Psychology. 56. p. 356-374.
Perception and Cognition Lab (University of Missouri): Bayes factor calculators. http://pcl.missouri.edu/bayesfactor
# NOT RUN {
## See specific functions for examples.
# }
Run the code above in your browser using DataLab