grapes-termin-grapes: Find a model term in a vector of model terms

%termin%R Documentation

Find a model term in a vector of model terms

Description

Find a model term in a vector of model terms

Usage

x %termin% table

Arguments

x

the terms to be matched

table

the terms to be matched against

Value

A logical vector of the same length as x, indicating if a match was located for each element of x.


BayesFactor documentation built on March 7, 2026, 5:06 p.m.